# -*- coding: utf-8 -*-

__author__ = "Jakrin Juangbhanich"
__email__ = "juangbhanich.k@gmail.com"
__version__ = "0.2.9"

import logmatic.log
from logmatic.log import debug, info, warning, error, critical, increment, gauge, event, get_instance
